Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(308)

Unified Diff: chrome/browser/extensions/default_apps.h

Issue 10692168: Moved ExternalExtensionLoaders/Providers into extensions namespace (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/default_apps.h
diff --git a/chrome/browser/extensions/default_apps.h b/chrome/browser/extensions/default_apps.h
index 254fa86f060accfee531512566e67dcd5d9d115b..3200bc910b9fdd48c772a94c2245783587bc3ce4 100644
--- a/chrome/browser/extensions/default_apps.h
+++ b/chrome/browser/extensions/default_apps.h
@@ -7,7 +7,7 @@
#pragma once
#include "base/basictypes.h"
-#include "chrome/browser/extensions/external_extension_provider_impl.h"
+#include "chrome/browser/extensions/external_provider_impl.h"
class PrefService;
class Profile;
@@ -32,19 +32,19 @@ enum InstallState {
void RegisterUserPrefs(PrefService* prefs);
// A specialization of the ExternalExtensionProviderImpl that conditionally
// installs apps from the chrome::DIR_DEFAULT_APPS location based on a
// preference in the profile.
-class Provider : public ExternalExtensionProviderImpl {
+class Provider : public extensions::ExternalProviderImpl {
public:
Provider(Profile* profile,
VisitorInterface* service,
- ExternalExtensionLoader* loader,
+ extensions::ExternalLoader* loader,
extensions::Extension::Location crx_location,
extensions::Extension::Location download_location,
int creation_flags);
- // ExternalExtensionProviderImpl overrides:
+ // extensions::ExternalProviderImpl overrides:
virtual void VisitRegisteredExtension() OVERRIDE;
private:
« no previous file with comments | « no previous file | chrome/browser/extensions/default_apps.cc » ('j') | chrome/browser/extensions/extension_service_unittest.cc » ('J')
@@ -32,19 +32,19 @@ enum InstallState {
void RegisterUserPrefs(PrefService* prefs);
-// A specialization of the ExternalExtensionProviderImpl that conditionally
+// A specialization of the extensions::ExternalProviderImpl that conditionally
// installs apps from the chrome::DIR_DEFAULT_APPS location based on a
// preference in the profile.

Powered by Google App Engine
This is Rietveld 408576698